==> apeman-commons-compiling-1.0.3.tgz: package/README.md <==
apeman-commons-compiling
===========

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]

apeman common module for compiling. 


Installation
------------

Install module via [npm][npm_url].

```bash
# Install as local module.
$ npm install apeman-commons-compiling --save
```

Usage
-----

### Concat Files

Concat string files.

```javascript
/**
 * This is an example to use concat files.
 */

"use strict";

var concatFiles = require('apeman-commons-compiling/lib/concat_files');

concatFiles([
    'src/javascript/*.js'
], 'dist/all.js', {
    unique: true
}, function (err) {
    /*...*/
});
```

License
-------

This software is released under the [MIT License][my_license_url].


Links
-----

+ [apeman][apeman_url]

[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
[my_repo_url]: https://github.com/apeman-repo/apeman-commons-compiling
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-commons-compiling
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-commons-compiling.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-commons-compiling/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-commons-compiling
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-commons-compiling.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/apeman-repo/apeman-commons-compiling.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-commons-compiling
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-commons-compiling.svg?style=flat

==> apeman-commons-compiling-1.1.3.tgz: package/README.md <==
apeman-commons-compiling
===========

[![Build Status][my_travis_badge_url]][my_travis_url]
[![Code Climate][my_codeclimate_badge_url]][my_codeclimate_url]
[![Code Coverage][my_codeclimate_coverage_badge_url]][my_codeclimate_url]
[![npm version][my_npm_budge_url]][my_npm_url]

apeman common module for compiling. 


Installation
------------

Install module via [npm][npm_url].

```bash
# Install as local module.
$ npm install apeman-commons-compiling --save
```

Usage
-----

### Concat Files

Concat string files.

```javascript
/**
 * This is an example to use `.concatFiles()`.
 */

"use strict";

var concatFiles = require('apeman-commons-compiling/lib/concat_files');

concatFiles([
    'src/javascript/*.js'
], 'dist/all.js', {
    unique: true
}, function (err) {
    /*...*/
});
```
### Render sass file.

Render sass file.

```javascript
/**
 * This is an example to use `.renderSass()`.
 */

"use strict";

var renderSass = require('apeman-commons-compiling/lib/render_sass');

renderSass('@import "mock-module.scss";@include define-main(#CDE);', "public/main.css", {
    includePaths: 'src/stylesheets'
}, function (err) {
    /*...*/
});
```

License
-------

This software is released under the [MIT License][my_license_url].


Links
-----

+ [apeman][apeman_url]

[npm_url]: https://www.npmjs.com/
[apeman_url]: https://github.com/apeman-repo/apeman
[my_repo_url]: https://github.com/apeman-repo/apeman-commons-compiling
[my_travis_url]: http://travis-ci.org/apeman-repo/apeman-commons-compiling
[my_travis_badge_url]: http://img.shields.io/travis/apeman-repo/apeman-commons-compiling.svg?style=flat
[my_license_url]: https://github.com/apeman-repo/apeman-commons-compiling/blob/master/LICENSE
[my_codeclimate_url]: http://codeclimate.com/github/apeman-repo/apeman-commons-compiling
[my_codeclimate_badge_url]: http://img.shields.io/codeclimate/github/apeman-repo/apeman-commons-compiling.svg?style=flat
[my_codeclimate_coverage_badge_url]: http://img.shields.io/codeclimate/coverage/github/apeman-repo/apeman-commons-compiling.svg?style=flat
[my_npm_url]: http://www.npmjs.org/package/apeman-commons-compiling
[my_npm_budge_url]: http://img.shields.io/npm/v/apeman-commons-compiling.svg?style=flat
